"""
Copyright: MAXON Computer GmbH
Author: Maxime Adam, Mike Udin

Description:
    - Creates a swatch group and adds colors to it from websites coolors.co and color.hailpixel.com.

Class/method highlighted:
    - c4d.modules.colorchooser.SwatchData
    - c4d.modules.colorchooser.SwatchGroup
    - maxon.ColorA

Compatible:
    - Win / Mac
    - R20, R21, S22
"""
import c4d
import maxon


def main():

    group_name = 'New group'

    # Checks Clipboard Type
    if c4d.GetClipboardType() != c4d.CLIPBOARDTYPE_STRING:
        c4d.gui.MessageDialog('No colors data in clipboard!')
        return

    # Checks Clipboard String
    color_string = c4d.GetStringFromClipboard()
    
    if color_string.startswith('/* CSV */'):
        color_string = color_string.splitlines()[1]
    elif color_string.startswith('https://color.hailpixel.com/#'):
        color_string = color_string.split('#')[1]
    else:
        c4d.gui.MessageDialog('No valid data in clipboard!')
        return
    
    # Creates a swatch data
    swatchData = c4d.modules.colorchooser.ColorSwatchData()
    if swatchData is None:
        raise MemoryError("Failed to create a ColorSwatchData.")

    # Loads the swatch data from the active document
    if not swatchData.Load(doc):
        raise RuntimeError("Failed to load the ColorSwatchData.")

    # Creates a swatch group
    group = swatchData.AddGroup(c4d.SWATCH_CATEGORY_DOCUMENT, group_name)
    if group is None:
        raise MemoryError("Failed to create a group.")

    for h in color_string.split(','):

        # Creates colors from hex-strings and stores them in the previously created group
        rgb = tuple(int(h[i:i+2], 16)/255.0 for i in (0, 2, 4))

        # Creates a maxon.ColorA for the current color
        col4 = maxon.ColorA()
        col4.r = rgb[0]
        col4.g = rgb[1]
        col4.b = rgb[2]
        col4.a = 1.0
        group.AddColor(col4)

    # Inserts the swatch group in the last position
    index = swatchData.GetGroupCount(c4d.SWATCH_CATEGORY_DOCUMENT) - 1
    swatchData.SetGroupAtIndex(index, group)

    # Saves the group into the active document
    swatchData.Save(doc)

    # Pushes an update event to Cinema 4D
    c4d.EventAdd()


if __name__ == '__main__':
    main()
